"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ad_record_1 = require("../records/ad.record");
const db_1 = require("../utils/db");
const defaultObj = {
    name: 'Test Name',
    description: 'blah',
    url: 'https://example.com',
    price: 0,
    latitude: 9,
    longitude: 9,
};
afterAll(() => __awaiter(void 0, void 0, void 0, function* () {
    yield db_1.pool.end();
}));
// ------------- getOne method ------------------------------------------------------
test('AdRecord.getOne returns data from database for one entry.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = yield ad_record_1.AdRecord.getOne('1');
    expect(ad).toBeDefined();
    expect(ad.id).toBe('1');
    expect(ad.name).toBe('Test');
    expect(ad.description).toBe('Test');
    expect(ad.latitude).toBe(90.0000000);
    expect(ad.longitude).toBe(90.0000000);
}));
test('AdRecord.getOne returns null from database for nonexistent entry', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = yield ad_record_1.AdRecord.getOne('---');
    expect(ad).toBeNull();
}));
// ------------- findAll method ------------------------------------------------------
test('AdRecord.findAll returns array of found entries.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_record_1.AdRecord.findAll('');
    expect(ads).not.toEqual([]);
    expect(ads[0].id).toBeDefined();
}));
test('AdRecord.findAll returns array of found entries when searching for "e".', () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_record_1.AdRecord.findAll('e');
    expect(ads).not.toEqual([]);
    expect(ads[0].id).toBeDefined();
}));
test('AdRecord.findAll returns empty array when searching for something does not exist.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_record_1.AdRecord.findAll('--------------');
    expect(ads).toEqual([]);
}));
test('AdRecord.findAll returns smaller (expected by the client) amount of data from database.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_record_1.AdRecord.findAll('');
    expect(ads[0].price).toBeDefined();
    expect(ads[0].description).toBeUndefined();
}));
// ------------- insert method ------------------------------------------------------
test('AdRecord.insert returns new UUID.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = new ad_record_1.AdRecord(defaultObj);
    yield ad.insert();
    expect(ad.id).toBeDefined();
    expect(typeof ad.id).toBe('string');
}));
test('AdRecord.insert inserts data to database.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = new ad_record_1.AdRecord(defaultObj);
    yield ad.insert();
    const foundAd = yield ad_record_1.AdRecord.getOne(ad.id);
    expect(foundAd).toBeDefined();
    expect(foundAd).not.toBeNull();
    expect(foundAd.id).toBe(ad.id);
}));
//# sourceMappingURL=ad.test.js.map